@@ -1,3 +1,5 @@
+import time
+
 import httpretty
 
 from remoteconfig import config, RemoteConfig
@@ -16,17 +18,19 @@ class TestRemoteConfig(object):
     # Cache duration on read
     updated_config_content = '[section]\n\nkey = updated\n'
     httpretty.register_uri(httpretty.GET, config_url, body=updated_config_content)
-    config.read(config_url, cache_duration=10)
+    config.read(config_url, cache_duration=1)
     assert config_content == str(config)
 
-    # Default cache duration
-    config2 = RemoteConfig(config_url, default_cache_duration=10, kv_sep=': ')
+    # Cache duration on init
+    config2 = RemoteConfig(config_url, cache_duration=1, kv_sep=': ')
     assert config_content.replace(' = ', ': ') == str(config2)
 
     # Using default cache duration
     config2.read(config_url)
     assert config_content.replace(' = ', ': ') == str(config2)
 
-    # Should update without cache duration
+    time.sleep(1)
+
+    # Should update after cache duration
     config.read(config_url)
     assert updated_config_content == str(config)
